=============================
Aruba Edge Connect Python SDK
=============================


.. raw:: html

   <object data="https://static.pepy.tech/personalized-badge/pyedgeconnect?period=total&units=none&left_color=grey&right_color=orange&left_text=PyPI%20Downloads"></object>

This package is a python wrapper for leveraging the API for Aruba
Orchestrator and Edge Connect SDWAN systems.

.. toctree::
   :caption: Introduction

   install
   quickstart
   logging

.. toctree::
   :maxdepth: 2
   :caption: Example Scripts

   examples/index

.. toctree::
   :caption: Package Structure and Logic

   package_structure
   sdk_logic
   code_formatting

.. toctree::
   :caption: Module Documentation

   pyedgeconnect

.. toctree::
   :maxdepth: 2
   :caption: Release Notes

   release-notes/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
